%define libmaj 0
%define libmin 9
%define librel 6
Release: 1

%define openssldir /etc/ssl

Summary: Secure Sockets Layer and cryptography libraries and tools
Name: openssl
Version: %{libmaj}.%{libmin}.%{librel}
Source0: ftp://ftp.openssl.org/source/%{name}-%{version}.tar.gz
Copyright: Freely distributable
Group: Applications/Cryptography
Provides: SSL
URL: http://www.openssl.org/
Packager: Ben H Kram <jargon@modulo.org>
BuildRoot: /var/tmp/%{name}-%{version}-root

%description
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols with full-strength cryptography world-wide. The project is
managed by a worldwide community of volunteers that use the Internet to
communicate, plan, and develop the OpenSSL tookit and its related
documentation. 

OpenSSL is based on the excellent SSLeay library developed from Eric A.
Young and Tim J. Hudson.  The OpenSSL toolkit is licensed under an
Apache-style licence, which basically means that you are free to get and
use it for commercial and non-commercial purposes. 

This package contains the base OpenSSL cryptography and SSL/TLS 
libraries and tools.

%package devel
Summary: Secure Sockets Layer and cryptography static libraries and headers
Group: Development/Libraries
Requires: openssl
%description devel
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols with full-strength cryptography world-wide. The project is
managed by a worldwide community of volunteers that use the Internet to
communicate, plan, and develop the OpenSSL tookit and its related
documentation. 

OpenSSL is based on the excellent SSLeay library developed from Eric A.
Young and Tim J. Hudson.  The OpenSSL toolkit is licensed under an
Apache-style licence, which basically means that you are free to get and
use it for commercial and non-commercial purposes. 

This package contains the OpenSSL cryptography and SSL/TLS 
static libraries and header files required when developing applications.

%package misc
Summary: OpenSSL X.509 tools
Group: Applications/Cryptography
Requires: openssl
%description misc
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols with full-strength cryptography world-wide. The project is
managed by a worldwide community of volunteers that use the Internet to
communicate, plan, and develop the OpenSSL tookit and its related
documentation. 

OpenSSL is based on the excellent SSLeay library developed from Eric A.
Young and Tim J. Hudson.  The OpenSSL toolkit is licensed under an
Apache-style licence, which basically means that you are free to get and
use it for commercial and non-commercial purposes. 

This package contains assorted scripts for X.509 certificate generation
and processing.

%prep

%setup -q

%build 

perl util/perlpath.pl /usr/bin/perl

%ifarch i386 i486 i586 i686
./Configure --prefix=/usr --openssldir=%{openssldir} linux-elf
%endif
%ifarch ppc
./Configure --prefix=/usr --openssldir=%{openssldir} linux-ppc 
%endif
%ifarch alpha
./Configure --prefix=/usr --openssldir=%{openssldir} linux-alpha-gcc
%endif
%ifarch sparc
./Configure --prefix=/usr --openssldir=%{openssldir} linux-sparcv7
%endif
%ifarch sparc64
./Configure --prefix=/usr --openssldir=%(openssldir) linux-sparcv9
%endif

LD_LIBRARY_PATH=`pwd` make
LD_LIBRARY_PATH=`pwd` make rehash
LD_LIBRARY_PATH=`pwd` make test
make linux-shared

%install
rm -rf $RPM_BUILD_ROOT
make install MANDIR=/usr/man INSTALL_PREFIX="$RPM_BUILD_ROOT"

# Rename manpages
for x in $RPM_BUILD_ROOT/usr/man/man*/* 
	do mv ${x} ${x}ssl
done

# Install RSAref stuff
install -m644 rsaref/rsaref.h $RPM_BUILD_ROOT/usr/include/openssl
install -m644 libRSAglue.a $RPM_BUILD_ROOT/usr/lib

# Make backwards-compatibility symlink to ssleay
ln -s /usr/bin/openssl $RPM_BUILD_ROOT/usr/bin/ssleay

# Install shared libs
install -m755 libcrypto.so.%{libmaj}.%{libmin}.%{librel} $RPM_BUILD_ROOT/usr/lib
install -m755 libssl.so.%{libmaj}.%{libmin}.%{librel} $RPM_BUILD_ROOT/usr/lib
(
	cd $RPM_BUILD_ROOT/usr/lib
	ln -s libcrypto.so.%{libmaj}.%{libmin}.%{librel} libcrypto.so.%{libmaj}
	ln -s libcrypto.so.%{libmaj}.%{libmin}.%{librel} libcrypto.so
	ln -s libssl.so.%{libmaj}.%{libmin}.%{librel} libssl.so.%{libmaj}
	ln -s libssl.so.%{libmaj}.%{libmin}.%{librel} libssl.so
)

# Move misc tools to /usr/bin
mv $RPM_BUILD_ROOT/%{openssldir}/misc/* $RPM_BUILD_ROOT/usr/bin

%clean
rm -rf $RPM_BUILD_ROOT

%files 
%defattr(0644,root,root,0755)
%doc CHANGES CHANGES.SSLeay LICENSE NEWS README
%doc doc

%attr(0755,root,root) /usr/bin/c_rehash
%attr(0755,root,root) /usr/bin/openssl
%attr(0755,root,root) /usr/bin/ssleay
%attr(0755,root,root) /usr/lib/*.so*
%attr(0644,root,root) /usr/man/man[157]/*

%attr(0644,root,root) %config(noreplace) %{openssldir}/openssl.cnf 
%dir %attr(0755,root,root) %{openssldir}/certs
%dir %attr(0750,root,root) %{openssldir}/private

%files devel
%defattr(0644,root,root,0755)
%attr(0644,root,root) /usr/lib/*.a
%attr(0644,root,root) /usr/include/openssl/*
%attr(0644,root,root) /usr/man/man[3]/*

%files misc
%attr(0755,root,root) /usr/bin/CA.pl
%attr(0755,root,root) /usr/bin/CA.sh
%attr(0755,root,root) /usr/bin/c_hash
%attr(0755,root,root) /usr/bin/c_info
%attr(0755,root,root) /usr/bin/c_issuer
%attr(0755,root,root) /usr/bin/c_name
%attr(0755,root,root) /usr/bin/der_chop

%post
ldconfig

%postun
ldconfig

%changelog
* Tue Oct 08 2000 Ben H Kram <jargon@modulo.org>
* Tue Aug 15 2000 Damien Miller <djm@mindrot.org>
- Neil McNeight <mcneight@umich.edu> fixed my speeeling misteaks
* Wed Aug 09 2000 Damien Miller <djm@mindrot.org>
- Sparc arch rules from Gregory Leblanc <GLeblanc@cu-portland.edu>
- Moved ssldir to /etc/ssl to be more like OpenBSD
- Moved misc tools to seperate package
- Marked openssl.cnf with noreplace
- Removed anon DH compile flag
* Sun Feb 27 2000 Damien Miller <djm@mindrot.org>
- Merged patches to spec
- Updated to 0.9.5beta2 (now with manpages)
* Sat Feb  5 2000 Michal Jaegermann <michal@harddata.com>
- added 'linux-alpha' to configuration
- fixed nasty absolute links
* Tue Jan 25 2000 Bennett Todd <bet@rahul.net>
- Added -DSSL_ALLOW_ADH, bumped Release to 4
* Thu Oct 14 1999 Damien Miller <djm@mindrot.org>
- Set default permissions
- Removed documentation from devel sub-package
* Thu Sep 30 1999 Damien Miller <djm@mindrot.org>
- Added "make test" stage
- GPG signed
* Tue Sep 10 1999 Damien Miller <damien@ibs.com.au>
- Updated to version 0.9.4
* Tue May 25 1999 Damien Miller <damien@ibs.com.au>
- Updated to version 0.9.3
- Added attributes for all files
- Paramatised openssl directory
* Sat Mar 20 1999 Carlo M. Arenas Belon <carenas@jmconsultores.com.pe>
- Added "official" bnrec patch and taking other out
- making a link from ssleay to openssl binary
- putting all changelog together on SPEC file
* Fri Mar  5 1999 Henri Gomez <gomez@slib.fr>
- Added bnrec patch
* Tue Dec 29 1998 Jonathan Ruano <kobalt@james.encomix.es>
- minimum spec and patches changes for openssl
- modified for openssl sources
* Sat Aug  8 1998 Khimenko Victor <khim@sch57.msk.ru>
- shared library creating process honours $RPM_OPT_FLAGS
- shared libarry supports threads (as well as static library)
* Wed Jul 22 1998 Khimenko Victor <khim@sch57.msk.ru>
- building of shared library completely reworked
* Tue Jul 21 1998 Khimenko Victor <khim@sch57.msk.ru>
- RPM is BuildRoot'ed
* Tue Feb 10 1998 Khimenko Victor <khim@sch57.msk.ru>
- all stuff is moved out of /usr/local
